@@ -80,7 +80,7 @@ class DynamicWriter:
         if key not in self.datatypes:
             raise KeyError(f"No defined data type for key {key}")
 
-    def write(self, data, overwrite: list):
+    def write(self, data, overwrite: list, meta={}):
         # Data is a dictionary, if not, make it one
         # Overwrite data is a list
         with h5py.File(self.file, "a") as store:
@@ -100,6 +100,9 @@ class DynamicWriter:
                 except Exception as e:
                     print(key, value)
                     raise (e)
+            for key, value in meta.items():
+                hgroup.attrs[key] = value
+
         return
 
 
@@ -113,7 +116,7 @@ class TilerWriter(DynamicWriter):
     }
     group = "trap_info"
 
-    def write(self, data, overwrite: list, tp: int):
+    def write(self, data, overwrite: list, tp: int, meta={}):
         """
         Skips writing data if it were to overwrite it,using drift as a marker
         """
@@ -126,8 +129,9 @@ class TilerWriter(DynamicWriter):
             if nprev and tp < nprev.shape[0]:
                 print(f"Tiler: Skipping timepoint {tp}")
                 skip = True
+
         if not skip:
-            super().write(data=data, overwrite=overwrite)
+            super().write(data=data, overwrite=overwrite, meta=meta)
 
 
 tile_size = 117
@@ -165,7 +169,7 @@ class BabyWriter(DynamicWriter):
         "cell_label": ((None,), np.uint16),
         "trap": ((None,), np.uint16),
         "timepoint": ((None,), np.uint16),
-        "mother_assign": ((None,), h5py.vlen_dtype(np.uint16)),
+        # "mother_assign": ((None,), h5py.vlen_dtype(np.uint16)),
         "mother_assign_dynamic": ((None,), np.uint16),
         "volumes": ((None,), np.float32),
     }
@@ -263,7 +267,7 @@ class BabyWriter(DynamicWriter):
         else:
             self.__append_edgemasks(hgroup, edgemasks, current_indices)
 
-    def write(self, data, overwrite: list, tp: int = None):
+    def write(self, data, overwrite: list, tp: int = None, meta={}):
         with h5py.File(self.file, "a") as store:
             hgroup = store.require_group(self.group)
 
@@ -295,6 +299,11 @@ class BabyWriter(DynamicWriter):
                 except Exception as e:
                     print(key, value)
                     raise (e)
+
+        # Meta
+        for key, value in meta.items():
+            hgroup.attrs[key] = value
+
         return
 
 
@@ -311,12 +320,27 @@ class LinearBabyWriter(DynamicWriter):
         "cell_label": ((None,), np.uint16),
         "trap": ((None,), np.uint16),
         "timepoint": ((None,), np.uint16),
-        "mother_assign": ((None,), h5py.vlen_dtype(np.uint16)),
+        # "mother_assign": ((None,), h5py.vlen_dtype(np.uint16)),
         "mother_assign_dynamic": ((None,), np.uint16),
         "volumes": ((None,), np.float32),
     }
     group = "cell_info"
 
+    def write(self, data, overwrite: list, tp=None, meta={}):
+        # Data is a dictionary, if not, make it one
+        # Overwrite data is a list
+
+        with h5py.File(self.file, "a") as store:
+            hgroup = store.require_group(self.group)
+            available_tps = hgroup.get("timepoint", None)
+            if not available_tps or tp not in np.unique(available_tps[()]):
+                super().write(data, overwrite)
+            else:
+                print(f"BabyWriter: Skipping tp {tp}")
+
+            for key, value in meta.items():
+                hgroup.attrs[key] = value
+
 
 class StateWriter(DynamicWriter):
     datatypes = {
